
/* Generated data (by glib-mkenums) */

#include "gcal-enum-types.h"

/* enumerations from "gcal-utils.h" */
#include "gcal-utils.h"

GType
gcal_window_view_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GCAL_WINDOW_VIEW_DAY,
			  "GCAL_WINDOW_VIEW_DAY",
			  "day" },
			{ GCAL_WINDOW_VIEW_WEEK,
			  "GCAL_WINDOW_VIEW_WEEK",
			  "week" },
			{ GCAL_WINDOW_VIEW_MONTH,
			  "GCAL_WINDOW_VIEW_MONTH",
			  "month" },
			{ GCAL_WINDOW_VIEW_YEAR,
			  "GCAL_WINDOW_VIEW_YEAR",
			  "year" },
			{ GCAL_WINDOW_VIEW_LIST,
			  "GCAL_WINDOW_VIEW_LIST",
			  "list" },
			{ GCAL_WINDOW_VIEW_SEARCH,
			  "GCAL_WINDOW_VIEW_SEARCH",
			  "search" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GcalWindowViewType"),
				values);
	}
	return the_type;
}

GType
event_editable_property_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ EVENT_SUMMARY,
			  "EVENT_SUMMARY",
			  "summary" },
			{ EVENT_START_DATE,
			  "EVENT_START_DATE",
			  "start-date" },
			{ EVENT_END_DATE,
			  "EVENT_END_DATE",
			  "end-date" },
			{ EVENT_LOCATION,
			  "EVENT_LOCATION",
			  "location" },
			{ EVENT_DESCRIPTION,
			  "EVENT_DESCRIPTION",
			  "description" },
			{ EVENT_SOURCE,
			  "EVENT_SOURCE",
			  "source" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("EventEditableProperty"),
				values);
	}
	return the_type;
}


/* Generated data ends here */

